==> janus-config-1.2.1.12-sources.jar: com/xforceplus/janus/config/core/config/CoreAutoconfig.java <==
package com.xforceplus.janus.config.core.config;

import com.xforceplus.janus.config.core.init.JanusConfigInitRunnner;
import com.xforceplus.janus.config.core.init.MonitorDbConfigHandler;
import com.xforceplus.janus.config.core.init.UploadProjectConfigHandler;
import com.xforceplus.janus.config.core.monitor.JanusUploader;
import com.xforceplus.janus.config.core.util.SpringContextUtils;

import org.apache.commons.lang3.StringUtils;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.util.List;

/**
 * @Author: xuchuanhou
 * @Date:2022/5/12下午3:25
 */
@Configuration
public class CoreAutoconfig {

    @Bean
    @ConfigurationProperties(prefix = "janus")
    public HttpConfig createHttpConfig() {
        return new HttpConfig();
    }

    @Bean
    public ConfigHttpBuilder createConfigBuilder(HttpConfig httpConfig, Environment environment) {
        if (httpConfig != null) {
            if (StringUtils.isBlank(httpConfig.getAuthentication())) {
                httpConfig.setAuthentication(environment.getProperty("janus.authentication"));
            }
            if (StringUtils.isBlank(httpConfig.getUrl())) {
                httpConfig.setAuthentication(environment.getProperty("janus.url"));
            }
            if (StringUtils.isBlank(httpConfig.getAction().getConfig())) {
                httpConfig.getAction().setConfig(environment.getProperty("janus.action.config"));
            }
            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.enable")) {
                httpConfig.getWebfilter().setEnable(Boolean.valueOf(environment.getProperty("janus.webfilter.enable")));
            }
            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.exclude")) {
                httpConfig.getWebfilter().setExclude(environment.getProperty("janus.webfilter.exclude"));
            }

            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.exclude")) {
                httpConfig.getWebfilter().setExclude(environment.getProperty("janus.webfilter.exclude"));
            }
        }


        return new ConfigHttpBuilder(httpConfig);
    }

    @Bean
    public JanusConfigInitRunnner createConfigRunner(List<ConfigHandler> configHandlerList, ConfigBuilder configBuilder,HttpConfig httpConfig) {
        return new JanusConfigInitRunnner(configHandlerList, configBuilder,httpConfig);
    }


    @Bean
    public MonitorDbConfigHandler createMonitorDbHandler(HttpConfig httpConfig) {
        return new MonitorDbConfigHandler(httpConfig);
    }


    @Bean
    public UploadProjectConfigHandler createUploadActionHandler(HttpConfig httpConfig) {
        return new UploadProjectConfigHandler(httpConfig);
    }

    @Bean
    public JanusUploader createJanusUploader(HttpConfig httpConfig) {
        return new JanusUploader(httpConfig);
    }

    @Bean
    public SpringContextUtils createSpringContextUtils(ApplicationContext applicationContext) {
        SpringContextUtils springContextUtils = new SpringContextUtils(applicationContext);
        return springContextUtils;
    }


}

==> janus-config-1.2.2.16-sources.jar: com/xforceplus/janus/config/core/config/CoreAutoconfig.java <==
package com.xforceplus.janus.config.core.config;

import com.xforceplus.janus.config.core.init.JanusConfigInitRunnner;
import com.xforceplus.janus.config.core.init.MonitorDbConfigHandler;
import com.xforceplus.janus.config.core.init.UploadProjectConfigHandler;
import com.xforceplus.janus.config.core.monitor.JanusUploader;
import com.xforceplus.janus.config.core.util.SpringContextUtils;

import org.apache.commons.lang3.StringUtils;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

import java.util.List;

/**
 * @Author: xuchuanhou
 * @Date:2022/5/12下午3:25
 */
@Configuration
public class CoreAutoconfig {

    @Bean
    @ConfigurationProperties(prefix = "janus")
    public HttpConfig createHttpConfig() {
        return new HttpConfig();
    }

    @Bean
    public ConfigHttpBuilder createConfigBuilder(HttpConfig httpConfig, Environment environment) {
        if (httpConfig != null) {
            if (StringUtils.isBlank(httpConfig.getAuthentication())) {
                httpConfig.setAuthentication(environment.getProperty("janus.authentication"));
            }
            if (StringUtils.isBlank(httpConfig.getUrl())) {
                httpConfig.setAuthentication(environment.getProperty("janus.url"));
            }
            if (StringUtils.isBlank(httpConfig.getAction().getConfig())) {
                httpConfig.getAction().setConfig(environment.getProperty("janus.action.config"));
            }
            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.enable")) {
                httpConfig.getWebfilter().setEnable(Boolean.valueOf(environment.getProperty("janus.webfilter.enable")));
            }
            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.exclude")) {
                httpConfig.getWebfilter().setExclude(environment.getProperty("janus.webfilter.exclude"));
            }

            if (httpConfig.getWebfilter() != null && environment.containsProperty("janus.webfilter.exclude")) {
                httpConfig.getWebfilter().setExclude(environment.getProperty("janus.webfilter.exclude"));
            }
        }


        return new ConfigHttpBuilder(httpConfig);
    }

    @Bean
    @ConditionalOnProperty(name = "janus.authentication")
    public JanusConfigInitRunnner createConfigRunner(List<ConfigHandler> configHandlerList, ConfigBuilder configBuilder,HttpConfig httpConfig) {
        return new JanusConfigInitRunnner(configHandlerList, configBuilder,httpConfig);
    }


    @Bean
    public MonitorDbConfigHandler createMonitorDbHandler(HttpConfig httpConfig) {
        return new MonitorDbConfigHandler(httpConfig);
    }


    @Bean
    public UploadProjectConfigHandler createUploadActionHandler(HttpConfig httpConfig) {
        return new UploadProjectConfigHandler(httpConfig);
    }

    @Bean
    public JanusUploader createJanusUploader(HttpConfig httpConfig) {
        return new JanusUploader(httpConfig);
    }

    @Bean
    public SpringContextUtils createSpringContextUtils(ApplicationContext applicationContext) {
        SpringContextUtils springContextUtils = new SpringContextUtils(applicationContext);
        return springContextUtils;
    }


}
